@@ -1,5 +1,4 @@
 import asyncio
-import time
 
 from aiozk import exc, WatchEvent
 
@@ -9,7 +8,7 @@ from .recipe import Recipe
 class Barrier(Recipe):
 
     def __init__(self, path):
-        super(Barrier, self).__init__()
+        super().__init__()
         self.path = path
 
     async def create(self):
@@ -23,12 +22,8 @@ class Barrier(Recipe):
             pass
 
     async def wait(self, timeout=None):
-        time_limit = None
-        if timeout is not None:
-            time_limit = time.time() + timeout
-
-        barrier_lifted = self.client.wait_for_event(
-            WatchEvent.DELETED, self.path
+        barrier_lifted = self.client.wait_for_events(
+            [WatchEvent.DELETED], self.path
         )
 
         exists = await self.client.exists(path=self.path, watch=True)
@@ -36,8 +31,8 @@ class Barrier(Recipe):
             return
 
         try:
-            if time_limit:
-                await asyncio.wait_for(barrier_lifted, time_limit)
+            if timeout:
+                await asyncio.wait_for(barrier_lifted, timeout)
             else:
                 await barrier_lifted
         except asyncio.TimeoutError:
